from setuptools import setup, find_packages


setup(
    name="whttpcats",
    version="1.0",
    packages=find_packages(),
    author="resweirdoo",
    author_email="weirdoo145@gmail.com",
    description="A minimal wrapper to https://http.cat"
)